.. REaLTabFormer documentation master file, created by
   sphinx-quickstart on Wed Jun  7 18:23:38 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.md
   :parser: myst_parser.sphinx_

Documentation
=============

.. toctree::
   :maxdepth: 4
   :caption: Contents

   self